@@ -1,6 +1,7 @@
 from logilab.common.decorators import monkeypatch
 from cubes.vcsfile import entities as vcsfile
 from cubes.vcreview import entities as vcsreview
+from cubes.tracker.entities import project as tracker
 
 @monkeypatch(vcsfile.Repository, 'project')
 @property
@@ -9,6 +10,13 @@ def project(self):
         return self.reverse_source_repository[0]
     return None
 
+@monkeypatch(tracker.Project, 'repository')
+@property
+def repository(self):
+    if self.source_repository:
+        return self.source_repository[0]
+
+
 class PatchReviewBehaviour(vcsreview.PatchReviewBehaviour):
     """Select a reviewer for a patch.
     Try first to filter cwusers to ones that are already reviewers of
