@@ -45,7 +45,7 @@ def related_eids(line):
         eids.extend(int(m) for m in TICKET_EID_RGX.findall(cmd))
     return eids
 
-def tickets(session, ticket_eids, repository_eid):
+def tickets(cnx, ticket_eids, repository_eid):
     """Return rset for a ticket referenced in a commit message.
 
     The ticket must come from a project using given repository as
@@ -55,8 +55,8 @@ def tickets(session, ticket_eids, repository_eid):
     """
     for ticket_eid in ticket_eids:
         try:
-            rset = session.execute('Any X, P WHERE X eid %(x)s, X concerns P',
-                                   {'x': ticket_eid})
+            rset = cnx.execute('Any X, P WHERE X eid %(x)s, X concerns P',
+                               {'x': ticket_eid})
         except TypeResolverException: # ticket_eid is not a ticket
             continue
         if not rset: # ticket_eid doesn't exist
@@ -91,11 +91,11 @@ class SearchRevisionTicketOp(hook.DataOperationMixIn,
     def precommit_event(self):
         for rev_eid in self.get_data():
             # search for instruction
-            rev = self.session.entity_from_eid(rev_eid)
+            rev = self.cnx.entity_from_eid(rev_eid)
             eids = closed_eids(rev.description)
-            for ticket in tickets(self.session, eids, rev.repository.eid):
+            for ticket in tickets(self.cnx, eids, rev.repository.eid):
                 if rev.phase == 'public':
-                    self.session.execute(_CLOSED_BY_RQL,
+                    self.cnx.execute(_CLOSED_BY_RQL,
                                          {'t': ticket.eid, 'r': rev.eid})
                     iwf = ticket.cw_adapt_to('IWorkflowable')
                     for tr in iwf.possible_transitions():
@@ -186,7 +186,7 @@ class PatchRevisionAdded(hook.Hook):
 # depending on trackervcs/forge import order. Import order is fixed using
 # __pkginfo__.__recommends__ so everything should be ok
 tracker.S_RELS.add('source_repository')
-tracker.O_RELS |= set(('from_repository', 'from_revision'))
+tracker.O_RELS |= set(('from_repository',))
 
 # registration control #########################################################
 
